SystemOrganization addCategory: #ConfigurationOfSwaUtil!

Object subclass: #ConfigurationOfSwaUtil
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSwaUtil'!

!ConfigurationOfSwaUtil class methodsFor: 'private' stamp: 'topa 10/6/2010 12:27'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSwaUtil class methodsFor: 'private' stamp: 'topa 10/6/2010 12:27'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfSwaUtil class methodsFor: 'metacello tool support' stamp: 'topa 10/6/2010 12:27'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSwaUtil class methodsFor: 'metacello tool support' stamp: 'topa 10/6/2010 12:27'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSwaUtil class methodsFor: 'loading' stamp: 'topa 10/6/2010 12:27'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfSwaUtil class methodsFor: 'metacello tool support' stamp: 'topa 10/6/2010 12:27'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSwaUtil class methodsFor: 'accessing' stamp: 'topa 10/6/2010 12:27'!
project

	^self new project! !

!ConfigurationOfSwaUtil class methodsFor: 'unloading Metacello' stamp: 'topa 10/6/2010 12:27'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSwaUtil methodsFor: 'baselines' stamp: 'mt 11/22/2010 16:23:23.605'!
baseline100: spec

	<version: '1.0-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.
		spec package: 'SwaUtil'.
		spec group: 'default' with: #('SwaUtil'). ].! !

!ConfigurationOfSwaUtil methodsFor: 'accessing' stamp: 'topa 10/6/2010 12:27'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSwaUtil methodsFor: 'versions' stamp: 'mt 10/28/2010 20:12:10.06'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec package: 'SwaUtil' with: 'SwaUtil-mt.43'].! !

!ConfigurationOfSwaUtil methodsFor: 'versions' stamp: 'mt 10/28/2010 20:12:28.238'!
version101: spec

	<version: '1.0.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec package: 'SwaUtil' with: 'SwaUtil-mt.46'].! !

!ConfigurationOfSwaUtil methodsFor: 'versions' stamp: 'mt 11/22/2010 16:20:50.094'!
versionHead: spec 
	
	<version: 'head' imports: #('1.0-baseline') >

	spec for: #common do: [
		spec blessing: #development.
		spec package: 'SwaUtil'].! !
